@@ -2,12 +2,17 @@ import enum
 
 
 class ParamDirection(enum.Flag):
+    """Use read for readOnly, write for writeOnly; read+write if unset"""
+
     read = enum.auto()
     write = enum.auto()
 
 
-class ParamPlacement(enum.Enum):
+class ParamLocation(enum.Enum):
     cookie = 'cookie'
     header = 'header'
     path = 'path'
     query = 'query'
+
+
+ParamPlacement = ParamLocation
